summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
-rwxr-xr-xrfc.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/rfc.sh b/rfc.sh
index 607fd7528fb..6ef13383500 100755
--- a/rfc.sh
+++ b/rfc.sh
@@ -18,7 +18,7 @@ done
shift $((OPTIND-1))
-branch="master";
+branch="experimental";
set_hooks_commit_msg()
{
@@ -72,8 +72,8 @@ check_backport()
{
moveon='N'
- # Backports are never made to master
- if [ $branch = "master" ]; then
+ # Backports are never made to 'master' or 'experimental'
+ if [ $branch = "master" -o $branch = "experimental" ]; then
return;
fi